@@ -26,6 +26,7 @@ from zope.traversing.interfaces import TraversalError
 # import local interfaces
 from ztfy.blog.browser.interfaces.container import IActionsColumn, IContainerTableViewActionsCell
 from ztfy.blog.interfaces.site import ISiteManager
+from ztfy.file.interfaces import IImageDisplay
 from ztfy.hplskin.interfaces import IBannerImage, ITopBannerImageAddFormMenuTarget, \
                                     ILeftBannerImageAddFormMenuTarget, IBannerManager, \
                                     IBannerManagerContentsView
@@ -37,10 +38,10 @@ from z3c.formjs import ajax
 from z3c.table.column import Column
 from z3c.template.template import getLayoutTemplate
 from zope.app.file.image import Image
-from zope.component import adapts, getAdapter, queryAdapter, queryMultiAdapter, getUtility
+from zope.component import adapts, adapter, getAdapter, queryAdapter, queryMultiAdapter, getUtility
 from zope.container.contained import Contained
 from zope.i18n import translate
-from zope.interface import implements, Interface
+from zope.interface import implements, implementer, Interface
 from zope.intid.interfaces import IIntIds
 from zope.location import locate
 from zope.publisher.browser import BrowserPage
@@ -139,8 +140,9 @@ class BannerManagerPreviewColumn(Column):
         image = IImage(item.image, None)
         if image is None:
             return u''
-        return '''<img src="%s/++display++64x64.jpeg" alt="%s" />''' % (absoluteURL(image, self.request),
-                                                                        traversing_api.getName(image))
+        display = IImageDisplay(image).getDisplay('64x64')
+        return '''<img src="%s" alt="%s" />''' % (absoluteURL(display, self.request),
+                                                  traversing_api.getName(image))
 
 
 class BannerManagerContentsViewActionsColumnCellAdapter(object):
@@ -168,13 +170,10 @@ class BannerManagerContentsViewActionsColumnCellAdapter(object):
 # Top banner custom classes extensions
 #
 
-class TopBannerManagerAdapter(object):
-
-    adapts(ISiteManager)
-    implements(IBannerManager)
-
-    def __new__(self, context):
-        return BannerManagerFactory(context, 'top')
+@adapter(ISiteManager)
+@implementer(IBannerManager)
+def TopBannerManagerFactory(context):
+    return BannerManagerFactory(context, 'top')
 
 
 class TopBannerContentsMenuItem(HPLSkinMenuItem):
@@ -196,13 +195,10 @@ class TopBannerContentsView(BannerManagerContentsView):
 # Left banner custom classes extensions
 #
 
-class LeftBannerManagerAdapter(object):
-
-    adapts(ISiteManager)
-    implements(IBannerManager)
-
-    def __new__(self, context):
-        return BannerManagerFactory(context, 'left')
+@adapter(ISiteManager)
+@implementer(IBannerManager)
+def LeftBannerManagerFactory(context):
+    return BannerManagerFactory(context, 'left')
 
 
 class LeftBannerContentsMenuItem(HPLSkinMenuItem):
